# Changelog

## [0.0.2] - 2023-02-01

### Added

- Added Loop class
- Made Events system
- Created Entities class
- Added Collisions
- Added `make` scenarios

### Changed

- `color` param in the `display_symbol` function now takes list of 3 numbers
- improved drawing methods

### Removed

- `curses` replaced with `blassed`

## [0.0.1] - 2023-01-28

_Initial release._

This release has been lost on pypi.org
